summaryrefslogtreecommitdiffstats
path: root/kugar/kudesigner/kudesigner_factory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kugar/kudesigner/kudesigner_factory.cpp')
-rw-r--r--kugar/kudesigner/kudesigner_factory.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kugar/kudesigner/kudesigner_factory.cpp b/kugar/kudesigner/kudesigner_factory.cpp
index 2c90d1d8..f8712f03 100644
--- a/kugar/kudesigner/kudesigner_factory.cpp
+++ b/kugar/kudesigner/kudesigner_factory.cpp
@@ -43,13 +43,13 @@ KudesignerFactory::~KudesignerFactory()
s_global = 0L;
}
-KParts::Part* KudesignerFactory::createPartObject( TQWidget *tqparentWidget, const char *widgetName, TQObject* tqparent, const char* name, const char* classname, const TQStringList & data )
+KParts::Part* KudesignerFactory::createPartObject( TQWidget *parentWidget, const char *widgetName, TQObject* tqparent, const char* name, const char* classname, const TQStringList & data )
{
// If classname is "KoDocument", our host is a koffice application
// otherwise, the host wants us as a simple part, so switch to readonly and single view.
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
- // tqparentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
- KudesignerDoc *part = new KudesignerDoc( tqparentWidget, widgetName, tqparent, name, !bWantKoDocument );
+ // parentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
+ KudesignerDoc *part = new KudesignerDoc( parentWidget, widgetName, tqparent, name, !bWantKoDocument );
if ( !bWantKoDocument )
part->setReadWrite( false );